==> dde-network-core_1.0.7.1.orig.tar.xz: dde-network-core-1.0.7.1/dde-network-dialog/translations/dde-network-dialog_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Ligar a uma rede oculta</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <source>Password required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de Segurança</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Principal</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não ligado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>A autenticar</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>A obter endereço de IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falha</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>A obter endereço</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede por cabo %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sem fios %1</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.69.orig.tar.xz: dde-network-core-1.0.69/dde-network-dialog/translations/dde-network-dialog_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Ligar a uma rede oculta</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <source>Password required to connect %1</source>
        <translation>Password necessária para conectar a %1</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Ligar</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nome (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de Segurança</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Principal</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desativado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Ligado mas sem acesso à Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não ligado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desligado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>A autenticar</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>A obter endereço de IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falha</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>A obter endereço</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede por cabo %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sem fios %1</translation>
    </message>
</context>
</TS>
